"use strict";
exports.__esModule = true;
var schematics_1 = require("@angular-devkit/schematics");
var tasks_1 = require("@angular-devkit/schematics/tasks");
var devDependencies = [
    {
        name: 'wallaby-webpack',
        version: '*'
    }
];
function default_1(_options) {
    return function (tree, context) {
        return schematics_1.chain([
            schematics_1.chain([addConfigFile()]),
            addLoadersToPackageJson(),
            addPackageInstallTask()
        ])(tree, context);
    };
}
exports["default"] = default_1;
function addConfigFile() {
    return function (tree, context) {
        var wallabyConfigSourceFileName = '/wallaby.js';
        var wallabyConfigFileName = '/wallaby.js';
        var files = schematics_1.url("../../files")(context);
        var createContent = files
            .read(wallabyConfigSourceFileName)
            .toString('utf-8');
        if (!tree.exists(wallabyConfigFileName)) {
            tree.create(wallabyConfigFileName, createContent);
        }
        return tree;
    };
}
function addLoadersToPackageJson() {
    return function (tree) {
        devDependencies.forEach(function (dependency) {
            addDependencyToPackageJson(tree, 'devDependencies', dependency.name, dependency.version);
        });
        return tree;
    };
}
function addPackageInstallTask() {
    return function (tree, context) {
        var depNames = devDependencies.map(function (d) { return d.name; }).join(' ');
        context.addTask(new tasks_1.NodePackageInstallTask({
            packageName: depNames
        }));
        return tree;
    };
}
/**
 * Adds a package to the package.json
 */
function addDependencyToPackageJson(tree, type, pkg, version) {
    if (version === void 0) { version = 'latest'; }
    if (tree.exists('/package.json')) {
        var sourceText = tree.read('/package.json').toString('utf-8');
        var json = JSON.parse(sourceText);
        if (!json[type]) {
            json[type] = {};
        }
        if (!json[type][pkg]) {
            json[type][pkg] = version;
        }
        tree.overwrite('/package.json', JSON.stringify(json, null, 2));
    }
    return tree;
}
exports.addDependencyToPackageJson = addDependencyToPackageJson;
//# sourceMappingURL=index.js.map